@@ -19,9 +19,9 @@ from dataclasses import dataclass
 if version_info[:2] >= (3, 8):
     from typing import Final
 else:
-    from typing_extensions import Final # type: ignore
+    from typing_extensions import Final  # type: ignore
 
-CORE_API_URL: Final[str] = "https://apis.pasqal.cloud/core"
+CORE_API_URL: Final[str] = "https://apis.pasqal.cloud/core-fast"
 ACCOUNT_API_URL: Final[str] = "https://apis.pasqal.cloud/account"
 
 
